==> regional-data-collection-model-2.0.0-4.13.0-165506-sources.jar: gr/cite/regional/data/collection/dataaccess/services/DataSubmissionService.java <==
package gr.cite.regional.data.collection.dataaccess.services;

import gr.cite.regional.data.collection.dataaccess.entities.DataSubmission;
import gr.cite.regional.data.collection.dataaccess.exceptions.ServiceException;

import java.util.List;

public interface DataSubmissionService {
	public DataSubmission addDataSubmission(DataSubmission dataSubmission) throws ServiceException;
	public DataSubmission updateDataSubmission(DataSubmission dataSubmission) throws ServiceException;
	public DataSubmission updateDataSubmissionAndData(DataSubmission dataSubmission) throws ServiceException;
	public DataSubmission updateDataSubmission(DataSubmission dataSubmission, boolean replace) throws ServiceException;
	public DataSubmission getDataSubmission(Integer id) throws ServiceException;
	List<DataSubmission> getDataSubmissionsByDataCollectionId(Integer id) throws ServiceException;
	List<DataSubmission> getDataSubmissionsByDataCollectionId(Integer id, boolean loadCDTs) throws ServiceException;
	public List<DataSubmission> getDataSubmissionsByDataCollectionAndOwner(Integer dataCollectionId, Integer ownerId) throws ServiceException;
	public List<DataSubmission> getDataSubmissionsByDataCollectionDomainAndOwner(Integer dataCollectionId, Integer domainId, Integer ownerId) throws ServiceException;
	public List<DataSubmission> getAllDataSubmissions() throws ServiceException;
	public void deleteDataSubmission(Integer id) throws ServiceException;
	public DataSubmission loadDetails(DataSubmission ds);
}

==> regional-data-collection-model-2.0.1-4.14.0-179618-sources.jar: gr/cite/regional/data/collection/dataaccess/services/DataSubmissionService.java <==
package gr.cite.regional.data.collection.dataaccess.services;

import gr.cite.regional.data.collection.dataaccess.entities.DataSubmission;
import gr.cite.regional.data.collection.dataaccess.entities.SubmissionStatus;
import gr.cite.regional.data.collection.dataaccess.exceptions.ServiceException;

import java.util.List;

public interface DataSubmissionService {
	public DataSubmission createDataSubmission(DataSubmission dataSubmission);
	public DataSubmission setDataSubmissionStatus(DataSubmission dataSubmission, SubmissionStatus status);
	public void addDataSubmissionCdts(DataSubmission newDataSubmission) throws ServiceException;
	public boolean canModifyDataSubmission(int id) throws  ServiceException;
	public DataSubmission updateDataSubmission(DataSubmission dataSubmission) throws ServiceException;
	public DataSubmission updateDataSubmissionAndData(DataSubmission dataSubmission) throws ServiceException;
	public DataSubmission updateDataSubmission(DataSubmission dataSubmission, boolean replace) throws ServiceException;
	public DataSubmission getDataSubmission(Integer id) throws ServiceException;
	List<DataSubmission> getDataSubmissionsByDataCollectionId(Integer id) throws ServiceException;
	List<DataSubmission> getDataSubmissionsByDataCollectionId(Integer id, boolean loadCDTs) throws ServiceException;
	public List<DataSubmission> getDataSubmissionsByDataCollectionAndOwner(Integer dataCollectionId, Integer ownerId) throws ServiceException;
	public List<DataSubmission> getDataSubmissionsByDataCollectionDomainAndOwner(Integer dataCollectionId, Integer domainId, Integer ownerId) throws ServiceException;
	public List<DataSubmission> getAllDataSubmissions() throws ServiceException;
	public void deleteDataSubmission(Integer id) throws ServiceException;
	public DataSubmission loadDetails(DataSubmission ds);
}
